@@ -24,7 +24,7 @@ __email__ = "nesaro@gmail.com"
 
 import logging
 LOG = logging.getLogger(__name__)
-from pydsl.Grammar.Definition import StringGrammarDefinition
+from pydsl.Grammar.Definition import String
 
 class Symbol(object):
     def __init__(self, weight):
@@ -54,9 +54,9 @@ class NonTerminalSymbol(Symbol):
 class TerminalSymbol(Symbol):
 
     def __init__(self, gd, weight=None, boundariesrules=None):
-        if isinstance(gd, StringGrammarDefinition):
+        if isinstance(gd, String):
             weight = weight or 99
-            boundariesrules = len(gd.string)
+            boundariesrules = len(gd)
         else:
             weight = weight or 49
         Symbol.__init__(self, weight)
@@ -88,17 +88,6 @@ class TerminalSymbol(Symbol):
     def __str__(self):
         return "<TS: " + str(self.gd) + ">"
 
-class UnknownSymbol(Symbol):
-    def __init__(self):
-        Symbol.__init__(self, 1)
-        self.boundariesrules = "any"
-
-    def __eq__(self, other):
-        return isinstance(other, UnknownSymbol)
-
-    def check(self, data):
-        return bool(data)
-
 class NullSymbol(Symbol):
     def __init__(self):
         Symbol.__init__(self, 100)
