@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #This file is part of pydsl.
 #
@@ -16,7 +16,6 @@
 #along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
 
 """Python Transformers"""
-from pydsl.Config import load
 
 __author__ = "Nestor Arocha"
 __copyright__ = "Copyright 2008-2013, Nestor Arocha"
@@ -63,10 +62,8 @@ def translator_factory(function):
         result = {}
         for key in originaldic:
             from pydsl.Check import checker_factory
-            result[key] = checker_factory(str(originaldic[key]))
+            result[key] = checker_factory(load(str(originaldic[key])))
         return result
-    if isinstance(function, str):
-        function = load(function)
     from pydsl.Grammar.Definition import PLYGrammar
     if isinstance(function, PLYGrammar):
         return PLYTranslator(function)
@@ -77,7 +74,9 @@ def translator_factory(function):
     from pyparsing import OneOrMore
     if isinstance(function, OneOrMore):
         return PyParsingTranslator(function)
+    if isinstance(function, PythonTranslator):
+        return function
     raise ValueError(function)
 
 def translate(definition, data):
-    return translator_factory(definition)(**data)
\ No newline at end of file
+    return translator_factory(definition)(**data)
